@@ -125,6 +125,13 @@ public final class RandomStringGenerator {
          */
         private List<Character> characterList;
 
+        /**
+         * Creates a new instance.
+         */
+        public Builder() {
+            // empty
+        }
+
         /**
          * Builds a new {@code RandomStringGenerator}.
          *
@@ -303,7 +310,6 @@ public final class RandomStringGenerator {
     /**
      * Constructs a new builder.
      * @return a new builder.
-     *
      * @since 1.11.0
      */
     public static Builder builder() {
