@@ -17,6 +17,7 @@
 
 package org.apache.commons.text.lookup;
 
+import java.net.InetAddress;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Path;
 import java.util.Base64;
@@ -115,6 +116,12 @@ import org.apache.commons.text.StringSubstitutor;
  * <td>1.3</td>
  * </tr>
  * <tr>
+ * <td>{@value #KEY_LOOPBACK_ADDRESS}</td>
+ * <td>{@link StringLookup}</td>
+ * <td>{@link #loopbackAddressStringLookup()}</td>
+ * <td>1.13.0</td>
+ * </tr>
+ * <tr>
  * <td>{@value #KEY_PROPERTIES}</td>
  * <td>{@link StringLookup}</td>
  * <td>{@link #propertiesStringLookup(Path...)}</td>
@@ -229,6 +236,14 @@ public final class StringLookupFactory {
          */
         private Path[] fences;
 
+        /**
+         * Creates a new instance.
+         */
+        public Builder() {
+            // empty
+        }
+
+
         @Override
         public StringLookupFactory get() {
             return new StringLookupFactory(fences);
@@ -241,7 +256,7 @@ public final class StringLookupFactory {
          * </p>
          *
          * @param fences Path resolution fences.
-         * @return this.
+         * @return {@code this} instance.
          */
         public Builder setFences(final Path... fences) {
             this.fences = fences;
@@ -280,7 +295,6 @@ public final class StringLookupFactory {
          */
         private static Map<String, StringLookup> createDefaultStringLookups() {
             final Map<String, StringLookup> lookupMap = new HashMap<>();
-
             addLookup(DefaultStringLookup.BASE64_DECODER, lookupMap);
             addLookup(DefaultStringLookup.BASE64_ENCODER, lookupMap);
             addLookup(DefaultStringLookup.CONST, lookupMap);
@@ -289,6 +303,7 @@ public final class StringLookupFactory {
             addLookup(DefaultStringLookup.FILE, lookupMap);
             addLookup(DefaultStringLookup.JAVA, lookupMap);
             addLookup(DefaultStringLookup.LOCAL_HOST, lookupMap);
+            addLookup(DefaultStringLookup.LOOPBACK_ADDRESS, lookupMap);
             addLookup(DefaultStringLookup.PROPERTIES, lookupMap);
             addLookup(DefaultStringLookup.RESOURCE_BUNDLE, lookupMap);
             addLookup(DefaultStringLookup.SYSTEM_PROPERTIES, lookupMap);
@@ -297,7 +312,6 @@ public final class StringLookupFactory {
             addLookup(DefaultStringLookup.XML, lookupMap);
             addLookup(DefaultStringLookup.XML_DECODER, lookupMap);
             addLookup(DefaultStringLookup.XML_ENCODER, lookupMap);
-
             return lookupMap;
         }
 
@@ -502,6 +516,13 @@ public final class StringLookupFactory {
      */
     public static final String KEY_LOCALHOST = "localhost";
 
+    /**
+     * Default lookup key for interpolation {@value #KEY_LOOPBACK_ADDRESS}.
+     *
+     * @since 1.13.0
+     */
+    public static final String KEY_LOOPBACK_ADDRESS = "loobackAddress";
+
     /**
      * Default lookup key for interpolation {@value #KEY_PROPERTIES}.
      *
@@ -747,8 +768,8 @@ public final class StringLookupFactory {
      * <p>
      * Sometimes it is necessary in a configuration file to refer to a constant defined in a class. This can be done with this lookup implementation. Variable
      * names must be in the format {@code apackage.AClass.AFIELD}. The {@code lookup(String)} method will split the passed in string at the last dot, separating
-     * the fully qualified class name and the name of the constant (i.e. <b>static final</b>) member field. Then the class is loaded and the field's value is
-     * obtained using reflection.
+     * the fully qualified class name and the name of the constant (i.e. <strong>static final</strong>) member field. Then the class is loaded and the field's
+     * value is obtained using reflection.
      * </p>
      * <p>
      * Once retrieved values are cached for fast access. This class is thread-safe. It can be used as a standard (i.e. global) lookup object and serve multiple
@@ -809,9 +830,9 @@ public final class StringLookupFactory {
     /**
      * Returns the DnsStringLookup singleton instance where the lookup key is one of:
      * <ul>
-     * <li><b>name</b>: for the local host name, for example {@code EXAMPLE} but also {@code EXAMPLE.apache.org}.</li>
-     * <li><b>canonical-name</b>: for the local canonical host name, for example {@code EXAMPLE.apache.org}.</li>
-     * <li><b>address</b>: for the local host address, for example {@code 192.168.56.1}.</li>
+     * <li><strong>name</strong>: for the local host name, for example {@code EXAMPLE} but also {@code EXAMPLE.apache.org}.</li>
+     * <li><strong>canonical-name</strong>: for the local canonical host name, for example {@code EXAMPLE.apache.org}.</li>
+     * <li><strong>address</strong>: for the local host address, for example {@code 192.168.56.1}.</li>
      * </ul>
      *
      * <p>
@@ -1051,12 +1072,12 @@ public final class StringLookupFactory {
      * The lookup keys with examples are:
      * </p>
      * <ul>
-     * <li><b>version</b>: "Java version 1.8.0_181"</li>
-     * <li><b>runtime</b>: "Java(TM) SE Runtime Environment (build 1.8.0_181-b13) from Oracle Corporation"</li>
-     * <li><b>vm</b>: "Java HotSpot(TM) 64-Bit Server VM (build 25.181-b13, mixed mode)"</li>
-     * <li><b>os</b>: "Windows 10 10.0, architecture: amd64-64"</li>
-     * <li><b>hardware</b>: "processors: 4, architecture: amd64-64, instruction sets: amd64"</li>
-     * <li><b>locale</b>: "default locale: en_US, platform encoding: iso-8859-1"</li>
+     * <li><strong>version</strong>: "Java version 1.8.0_181"</li>
+     * <li><strong>runtime</strong>: "Java(TM) SE Runtime Environment (build 1.8.0_181-b13) from Oracle Corporation"</li>
+     * <li><strong>vm</strong>: "Java HotSpot(TM) 64-Bit Server VM (build 25.181-b13, mixed mode)"</li>
+     * <li><strong>os</strong>: "Windows 10 10.0, architecture: amd64-64"</li>
+     * <li><strong>hardware</strong>: "processors: 4, architecture: amd64-64, instruction sets: amd64"</li>
+     * <li><strong>locale</strong>: "default locale: en_US, platform encoding: iso-8859-1"</li>
      * </ul>
      *
      * <p>
@@ -1084,11 +1105,11 @@ public final class StringLookupFactory {
     }
 
     /**
-     * Returns the LocalHostStringLookup singleton instance where the lookup key is one of:
+     * Returns the InetAddressStringLookup instance where the lookup key for {@link InetAddress#getLocalHost()} is one of:
      * <ul>
-     * <li><b>name</b>: for the local host name, for example {@code EXAMPLE}.</li>
-     * <li><b>canonical-name</b>: for the local canonical host name, for example {@code EXAMPLE.apache.org}.</li>
-     * <li><b>address</b>: for the local host address, for example {@code 192.168.56.1}.</li>
+     * <li><strong>name</strong>: for the local host name, for example {@code EXAMPLE}.</li>
+     * <li><strong>canonical-name</strong>: for the local canonical host name, for example {@code EXAMPLE.apache.org}.</li>
+     * <li><strong>address</strong>: for the local host address, for example {@code 192.168.56.1}.</li>
      * </ul>
      *
      * <p>
@@ -1109,10 +1130,42 @@ public final class StringLookupFactory {
      * The above examples convert {@code "canonical-name"} to the current host name, for example, {@code "EXAMPLE.apache.org"}.
      * </p>
      *
-     * @return The DateStringLookup singleton instance.
+     * @return The InetAddressStringLookup singleton instance.
      */
     public StringLookup localHostStringLookup() {
-        return LocalHostStringLookup.INSTANCE;
+        return InetAddressStringLookup.LOCAL_HOST;
+    }
+
+    /**
+     * Returns the InetAddressStringLookup instance where the lookup key for {@link InetAddress#getLoopbackAddress()} is one of:
+     * <ul>
+     * <li><strong>name</strong>: for the local host name, for example {@code EXAMPLE}.</li>
+     * <li><strong>canonical-name</strong>: for the local canonical host name, for example {@code EXAMPLE.apache.org}.</li>
+     * <li><strong>address</strong>: for the local host address, for example {@code 192.168.56.1}.</li>
+     * </ul>
+     *
+     * <p>
+     * Using a {@link StringLookup} from the {@link StringLookupFactory}:
+     * </p>
+     *
+     * <pre>
+     * StringLookupFactory.INSTANCE.loopbackAddressStringLookup().lookup("canonical-name");
+     * </pre>
+     * <p>
+     * Using a {@link StringSubstitutor}:
+     * </p>
+     *
+     * <pre>
+     * StringSubstitutor.createInterpolator().replace("... ${loopbackAddress:canonical-name} ..."));
+     * </pre>
+     * <p>
+     * The above examples convert {@code "canonical-name"} to the current host name, for example, {@code "EXAMPLE.apache.org"}.
+     * </p>
+     *
+     * @return The InetAddressStringLookup singleton instance.
+     */
+    public StringLookup loopbackAddressStringLookup() {
+        return InetAddressStringLookup.LOOPACK_ADDRESS;
     }
 
     /**
